@@ -10,10 +10,6 @@
 #ifndef __CDUNIXH__
 #define __CDUNIXH__
 
-#ifdef __GNUG__
-#pragma interface "cdunix.h"
-#endif
-
 #include "wx/defs.h"
 #include "wx/object.h"
 #include "wx/string.h"
