@@ -4,16 +4,12 @@
 // Date: 08/11/1999
 // Author: Guilhem Lavaux <lavaux@easynet.fr> (C) 1999
 // License:    wxWindows license
-// CVSID: $Id: sndaiff.h,v 1.2.4.1 2004/11/22 20:04:46 JS Exp $
+// CVSID: $Id: sndaiff.h,v 1.2.4.2 2005/06/20 17:33:33 MR Exp $
 // License:    wxWindows license
 // --------------------------------------------------------------------------
 #ifndef _WX_SNDAIFF_H
 #define _WX_SNDAIFF_H
 
-#ifdef __GNUG__
-#pragma interface "sndaiff.h"
-#endif
-
 #include "wx/defs.h"
 #include "wx/stream.h"
 #include "wx/mmedia/sndbase.h"
