@@ -3,7 +3,7 @@
 // Purpose:     XML resource handler for wxBoxSizer
 // Author:      Vaclav Slavik
 // Created:     2000/04/24
-// RCS-ID:      $Id: xh_sizer.h,v 1.2 2002/09/07 12:10:21 GD Exp $
+// RCS-ID:      $Id: xh_sizer.h,v 1.2.2.1 2005/06/20 17:33:53 MR Exp $
 // Copyright:   (c) 2000 Vaclav Slavik
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -11,10 +11,6 @@
 #ifndef _WX_XH_SIZER_H_
 #define _WX_XH_SIZER_H_
 
-#if defined(__GNUG__) && !defined(__APPLE__)
-#pragma interface "xh_sizer.h"
-#endif
-
 #include "wx/xrc/xmlres.h"
 
 
