@@ -4,15 +4,11 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     12/07/98
-// RCS-ID:      $Id: cspalette.cpp,v 1.6 2002/03/21 10:32:03 JS Exp $
+// RCS-ID:      $Id: cspalette.cpp,v 1.6.2.1 2005/06/20 17:34:18 MR Exp $
 // Copyright:   (c) Julian Smart
 // Licence:   	wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-// #pragma implementation
-#endif
-
 // For compilers that support precompilation, includes "wx.h".
 #include "wx/wxprec.h"
 
