@@ -6,38 +6,19 @@
 // Licence:     wxWindows Licence
 /////////////////////////////////////////////////////////////////////////////
 
-/*
+#ifndef _WX_FS_INET_H_
+#define _WX_FS_INET_H_
 
-REMARKS : 
-
-This FS creates local cache (in /tmp directory). The cache is freed
-on program exit.
-
-Size of cache is limited to cca 1000 items (due to GetTempFileName
-limitation)
-
-
-*/
-
-#ifdef __GNUG__
-#pragma interface "fs_inet.h"
-#endif
-
-#include "wx/wxprec.h"
-
-#ifdef __BORDLANDC__
-#pragma hdrstop
-#endif
+#include "wx/defs.h"
 
 #if wxUSE_FILESYSTEM && wxUSE_FS_INET && wxUSE_STREAMS && wxUSE_SOCKETS
 
 #ifndef WXPRECOMP
-#include "wx/wx.h"
+    #include "wx/hash.h"
 #endif
 
 #include "wx/filesys.h"
 
-
 //--------------------------------------------------------------------------------
 // wxInternetFSHandler
 //--------------------------------------------------------------------------------
@@ -56,3 +37,5 @@ class WXDLLEXPORT wxInternetFSHandler : public wxFileSystemHandler
 #endif
   // wxUSE_FILESYSTEM && wxUSE_FS_INET && wxUSE_STREAMS && wxUSE_SOCKETS
 
+#endif // _WX_FS_INET_H_
+
