@@ -1,21 +1,17 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        dcmemory.h
+// Name:        wx/msw/dcmemory.h
 // Purpose:     wxMemoryDC class
 // Author:      Julian Smart
 // Modified by:
 // Created:     01/02/97
-// RCS-ID:      $Id: dcmemory.h,v 1.5 2000/02/17 20:36:51 JS Exp $
+// RCS-ID:      $Id: dcmemory.h,v 1.6.2.1 2005/06/20 17:37:56 MR Exp $
 // Copyright:   (c) Julian Smart
-// Licence:   	wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
 #ifndef _WX_DCMEMORY_H_
 #define _WX_DCMEMORY_H_
 
-#ifdef __GNUG__
-#pragma interface "dcmemory.h"
-#endif
-
 #include "wx/dcclient.h"
 
 class WXDLLEXPORT wxMemoryDC : public wxDC
@@ -24,13 +20,19 @@ public:
     wxMemoryDC();
     wxMemoryDC(wxDC *dc); // Create compatible DC
 
-    ~wxMemoryDC();
-
-    virtual void DoDrawRectangle(wxCoord x, wxCoord y, wxCoord width, wxCoord height);
     virtual void SelectObject(const wxBitmap& bitmap);
 
+protected:
+    // override some base class virtuals
+    virtual void DoDrawRectangle(wxCoord x, wxCoord y, wxCoord width, wxCoord height);
     virtual void DoGetSize(int* width, int* height) const;
 
+    // create DC compatible with the given one or screen if dc == NULL
+    bool CreateCompatible(wxDC *dc);
+
+    // initialize the newly created DC
+    void Init();
+
 private:
     DECLARE_DYNAMIC_CLASS(wxMemoryDC)
 };
