@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     01/02/97
-// RCS-ID:      $Id: font.h,v 1.19.2.1 2002/09/22 20:58:43 VZ Exp $
+// RCS-ID:      $Id: font.h,v 1.19.2.2 2005/06/20 17:37:58 MR Exp $
 // Copyright:   (c) Julian Smart
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
@@ -12,10 +12,6 @@
 #ifndef _WX_FONT_H_
 #define _WX_FONT_H_
 
-#ifdef __GNUG__
-    #pragma interface "font.h"
-#endif
-
 // ----------------------------------------------------------------------------
 // wxFont
 // ----------------------------------------------------------------------------
