@@ -4,15 +4,11 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     04/01/98
-// RCS-ID:      $Id: prop.cpp,v 1.23.2.1 2000/04/01 23:19:11 VZ Exp $
+// RCS-ID:      $Id: prop.cpp,v 1.28.2.1 2005/06/20 17:41:46 MR Exp $
 // Copyright:   (c) Julian Smart
-// Licence:   	wxWindows licence
+// Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-#pragma implementation "prop.h"
-#endif
-
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
@@ -20,8 +16,9 @@
 #pragma hdrstop
 #endif
 
+#if wxUSE_PROPSHEET
+
 #ifndef WX_PRECOMP
-#include "wx/wx.h"
 #endif
 
 #include "wx/debug.h"
@@ -46,6 +43,7 @@ wxPropertyValue::wxPropertyValue(void)
 }
 
 wxPropertyValue::wxPropertyValue(const wxPropertyValue& copyFrom)
+    : wxObject()
 {
   m_value.string = (wxChar*) NULL;
   m_modifiedFlag = FALSE;
@@ -564,7 +562,7 @@ void wxPropertyValue::WritePropertyType(wxString& stream)    // Write as any oth
           expr->WritePropertyType(stream);
           expr = expr->m_next;
           if (expr)
-	    stream.Append( wxT(", ") );
+        stream.Append( wxT(", ") );
         }
         stream.Append( wxT("]") );
       }
@@ -833,6 +831,7 @@ wxProperty::wxProperty(void)
 }
 
 wxProperty::wxProperty(wxProperty& copyFrom)
+    : wxObject()
 {
   m_value = copyFrom.GetValue();
   m_name = copyFrom.GetName();
@@ -1006,14 +1005,14 @@ void wxPropertySheet::RemoveProperty(const wxString& name)
   if(node)
   {
     wxProperty *prop = (wxProperty *)node->Data();
- 	delete prop;
+     delete prop;
     m_properties.DeleteNode(node);
   }
-}	
+}    
 
 bool wxPropertySheet::HasProperty(const wxString& name) const
 {
-	return (GetProperty(name)?TRUE:FALSE);
+    return (GetProperty(name)?TRUE:FALSE);
 }
 
 // Clear all properties
@@ -1095,10 +1094,10 @@ wxPropertyValidator::~wxPropertyValidator(void)
 {}
 
 bool wxPropertyValidator::StringToFloat (wxChar *s, float *number) {
-	double num;
-	bool ok = StringToDouble (s, &num);
-	*number = (float) num;
-	return ok;
+    double num;
+    bool ok = StringToDouble (s, &num);
+    *number = (float) num;
+    return ok;
 }
 
 bool wxPropertyValidator::StringToDouble (wxChar *s, double *number) {
@@ -1106,20 +1105,20 @@ bool wxPropertyValidator::StringToDouble (wxChar *s, double *number) {
     wxChar *value_ptr;
     *number = wxStrtod (s, &value_ptr);
     if (value_ptr) {
-		int len = wxStrlen (value_ptr);
-		for (int i = 0; i < len; i++) {
-			ok = (wxIsspace (value_ptr[i]) != 0);
-			if (!ok) return FALSE;
-		}
+        int len = wxStrlen (value_ptr);
+        for (int i = 0; i < len; i++) {
+            ok = (wxIsspace (value_ptr[i]) != 0);
+            if (!ok) return FALSE;
+        }
     }
     return ok;
 }
 
 bool wxPropertyValidator::StringToInt (wxChar *s, int *number) {
-	long num;
-	bool ok = StringToLong (s, &num);
-	*number = (int) num;
-	return ok;
+    long num;
+    bool ok = StringToLong (s, &num);
+    *number = (int) num;
+    return ok;
 }
 
 bool wxPropertyValidator::StringToLong (wxChar *s, long *number) {
@@ -1127,31 +1126,33 @@ bool wxPropertyValidator::StringToLong (wxChar *s, long *number) {
     wxChar *value_ptr;
     *number = wxStrtol (s, &value_ptr, 10);
     if (value_ptr) {
-		int len = wxStrlen (value_ptr);
-		for (int i = 0; i < len; i++) {
-			ok = (wxIsspace (value_ptr[i]) != 0);
-			if (!ok) return FALSE;
-		}
+        int len = wxStrlen (value_ptr);
+        for (int i = 0; i < len; i++) {
+            ok = (wxIsspace (value_ptr[i]) != 0);
+            if (!ok) return FALSE;
+        }
     }
     return ok;
 }
 
 wxChar *wxPropertyValidator::FloatToString (float number) {
-	static wxChar buf[20];
-	wxSprintf (buf, wxT("%.6g"), number);
-	return buf;
+    static wxChar buf[20];
+    wxSnprintf (buf, 20, wxT("%.6g"), number);
+    return buf;
 }
 
 wxChar *wxPropertyValidator::DoubleToString (double number) {
-	static wxChar buf[20];
-	wxSprintf (buf, wxT("%.6g"), number);
-	return buf;
+    static wxChar buf[20];
+    wxSnprintf (buf, 20, wxT("%.6g"), number);
+    return buf;
 }
 
 wxChar *wxPropertyValidator::IntToString (int number) {
-	return ::IntToString (number);
+    return ::IntToString (number);
 }
 
 wxChar *wxPropertyValidator::LongToString (long number) {
-	return ::LongToString (number);
+    return ::LongToString (number);
   }
+
+#endif // wxUSE_PROPSHEET
