@@ -2,15 +2,11 @@
 // Name:        gtk/fontdlg.cpp
 // Purpose:     wxFontDialog
 // Author:      Robert Roebling
-// Id:          $Id: fontdlg.cpp,v 1.18.2.2 2003/02/11 11:35:12 RR Exp $
+// Id:          $Id: fontdlg.cpp,v 1.18.2.3 2005/06/20 17:42:04 MR Exp $
 // Copyright:   (c) 1998 Robert Roebling
 // Licence:     wxWindows licence
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-#pragma implementation "fontdlg.h"
-#endif
-
 #include "wx/defs.h"
 
 #if wxUSE_FONTDLG
