@@ -4,7 +4,7 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     04/01/98
-// RCS-ID:      $Id: brush.cpp,v 1.12.2.1 2002/09/21 23:01:25 VZ Exp $
+// RCS-ID:      $Id: brush.cpp,v 1.12.2.2 2005/06/20 17:43:49 MR Exp $
 // Copyright:   (c) Julian Smart and Markus Holzem
 // Licence:     wxWindows license
 /////////////////////////////////////////////////////////////////////////////
@@ -13,10 +13,6 @@
 // declarations
 // ============================================================================
 
-#ifdef __GNUG__
-#pragma implementation "brush.h"
-#endif
-
 // ----------------------------------------------------------------------------
 // headers
 // ----------------------------------------------------------------------------
