@@ -4,15 +4,11 @@
 // Author:      Julian Smart
 // Modified by:
 // Created:     04/01/98
-// RCS-ID:      $Id: reswrite.cpp,v 1.15.2.1 2000/04/22 14:41:06 JS Exp $
+// RCS-ID:      $Id: reswrite.cpp,v 1.20.2.1 2005/06/20 17:45:17 MR Exp $
 // Copyright:   (c) Julian Smart
 // Licence:   	wxWindows license
 /////////////////////////////////////////////////////////////////////////////
 
-#ifdef __GNUG__
-#pragma implementation
-#endif
-
 // For compilers that support precompilation, includes "wx/wx.h".
 #include "wx/wxprec.h"
 
@@ -36,6 +32,8 @@
 
 #include "reseditr.h"
 
+static char deBuffer[512];
+
 char *SafeString(char *s);
 char *SafeWord(const wxString& s);
 
@@ -569,10 +567,10 @@ char *SafeString(const wxString& s)
         return "NULL";
     else
     {
-        strcpy(wxBuffer, "\"");
-        strcat(wxBuffer, s);
-        strcat(wxBuffer, "\"");
-        return wxBuffer;
+        strcpy(deBuffer, "\"");
+        strcat(deBuffer, s);
+        strcat(deBuffer, "\"");
+        return deBuffer;
     }
 }
 
@@ -586,7 +584,7 @@ char *SafeWord(const wxString& s)
         return "''";
     else
     {
-        dp = wxBuffer;
+        dp = deBuffer;
         cp = s.c_str();
         *dp++ = '\'';
         while(*cp != 0) {
@@ -604,7 +602,7 @@ char *SafeWord(const wxString& s)
         *dp++ = '\'';
         *dp++ = 0;
         
-        return wxBuffer;
+        return deBuffer;
     }
 }
 
