@@ -1,4 +1,5 @@
 
+# aliases
 wxShapeCanvas =       wxPyShapeCanvas
 wxShapeEvtHandler =   wxPyShapeEvtHandler
 wxShape =             wxPyShape
@@ -17,20 +18,24 @@ wxControlPoint =      wxPyControlPoint
 
 # Stuff these names into the wx namespace so wxPyConstructObject can find them
 import wx
+wx.wxArrowHeadPtr         = wxArrowHeadPtr
+wx.wxControlPointPtr      = wxPyControlPointPtr
+wx.wxDiagramPtr           = wxDiagramPtr
+wx.wxOGLConstraintPtr     = wxOGLConstraintPtr
+wx.wxPseudoMetaFilePtr    = wxPseudoMetaFile
+wx.wxPyBitmapShapePtr     = wxPyBitmapShapePtr
+wx.wxPyCircleShapePtr     = wxPyCircleShapePtr
+wx.wxPyCompositeShapePtr  = wxPyCompositeShapePtr
+wx.wxPyControlPointPtr    = wxPyControlPointPtr
+wx.wxPyDividedShapePtr    = wxPyDividedShapePtr
+wx.wxPyDivisionShapePtr   = wxPyDivisionShapePtr
+wx.wxPyDrawnShapePtr      = wxPyDrawnShapePtr
+wx.wxPyEllipseShapePtr    = wxPyEllipseShapePtr
+wx.wxPyLineShapePtr       = wxPyLineShapePtr
+wx.wxPyPolygonShapePtr    = wxPyPolygonShapePtr
+wx.wxPyRectangleShapePtr  = wxPyRectangleShapePtr
 wx.wxPyShapeCanvasPtr     = wxPyShapeCanvasPtr
 wx.wxPyShapeEvtHandlerPtr = wxPyShapeEvtHandlerPtr
 wx.wxPyShapePtr           = wxPyShapePtr
-wx.wxPyRectangleShapePtr  = wxPyRectangleShapePtr
-wx.wxPyBitmapShapePtr     = wxPyBitmapShapePtr
-wx.wxPyDrawnShapePtr      = wxPyDrawnShapePtr
-wx.wxPyCompositeShapePtr  = wxPyCompositeShapePtr
-wx.wxPyDividedShapePtr    = wxPyDividedShapePtr
-wx.wxPyDivisionShapePtr   = wxPyDivisionShapePtr
-wx.wxPyEllipseShapePtr    = wxPyEllipseShapePtr
-wx.wxPyCircleShapePtr     = wxPyCircleShapePtr
-wx.wxPyLineShapePtr       = wxPyLineShapePtr
-wx.wxPyPolygonShapePtr    = wxPyPolygonShapePtr
 wx.wxPyTextShapePtr       = wxPyTextShapePtr
 wx.wxShapeRegionPtr       = wxShapeRegionPtr
-wx.wxOGLConstraintPtr     = wxOGLConstraintPtr
-wx.wxControlPointPtr      = wxPyControlPointPtr
